@@ -18,6 +18,15 @@ use constant DEFAULT_VIDEO_WIDTH  => 640;
 
 =head1 ATTRIBUTES
 
+=head2 error
+
+  my $err = $link->error;
+  $link   = $link->error({message => "Some error"});
+
+Get or set error. Default to C<undef> on no error.
+
+=head2 etag
+
 =head2 media_id
 
 Returns the part of the URL identifying the media. Default is empty string.
@@ -38,8 +47,12 @@ Holds a L<Mojo::URL> object.
 
 =cut
 
+has error => undef;
+has etag  => sub {
+  eval { shift->_tx->res->headers->etag } // '';
+};
 has media_id => '';
-sub provider_name { ucfirst shift->url->host }
+sub provider_name { ucfirst(shift->url->host || '') }
 has ua  => sub { die "Required in constructor" };
 has url => sub { shift->_tx->req->url };
 
@@ -152,6 +165,8 @@ sub to_embed {
   my $url  = $self->url;
   my @args;
 
+  return sprintf '<a href="#">%s</a>', $self->provider_name unless $url->host;
+
   push @args, target => '_blank';
   push @args, title => "Content-Type: @{[$self->_tx->res->headers->content_type]}" if $self->_tx;
 
@@ -173,7 +188,7 @@ sub TO_JSON {
     # width => $self->DEFAULT_VIDEO_WIDTH,
     html          => $self->to_embed,
     provider_name => $self->provider_name,
-    provider_url  => Mojo::URL->new(host => $url->host, scheme => $url->scheme),
+    provider_url  => $url->host ? Mojo::URL->new(host => $url->host, scheme => $url->scheme || 'http') : '',
     type          => 'rich',
     url           => $url,
 
@@ -191,7 +206,7 @@ sub _iframe {
     mozallowfullscreen    => undef,
     scrolling             => 'no',
     class                 => 'link-embedder',
-    @_
+    @_, 'Your browser is super old.',
   );
 }
 
