@@ -44,18 +44,43 @@ sub provider_name {'ix.io'}
 
 sub learn {
   my ($self, $c, $cb) = @_;
-  my $media_id = $self->media_id or return $self->SUPER::learn($c, $cb);
+  my $raw_url = $self->raw_url or return $self->SUPER::learn($c, $cb);
 
   $self->ua->get(
-    "http://ix.io/$media_id",
+    $raw_url,
     sub {
       my ($ua, $tx) = @_;
-      $self->{text} = $tx->res->body if $tx->success;
+      $self->{text} = Mojo::Util::xml_escape($tx->res->body) if $tx->success;
       $self->$cb;
     },
   );
 }
 
+=head2 pretty_url
+
+Returns a pretty version of the L</url>. The default is to return a cloned
+version of L</url>.
+
+=cut
+
+sub pretty_url {
+  my $self = shift;
+  my $media_id = $self->media_id or return $self->SUPER::pretty_url;
+
+  Mojo::URL->new("http://ix.io/$media_id/");
+}
+
+=head2 raw_url
+
+=cut
+
+sub raw_url {
+  my $self = shift;
+  my $media_id = $self->media_id or return;
+
+  Mojo::URL->new("http://ix.io/$media_id");
+}
+
 =head1 AUTHOR
 
 Jan Henning Thorsen
